========
Verifone
========


.. image:: https://img.shields.io/pypi/v/verifone.svg
        :target: https://pypi.python.org/pypi/verifone

.. image:: https://img.shields.io/travis/vilkasgroup/Verifone.svg
        :target: https://travis-ci.org/vilkasgroup/Verifone

.. image:: https://readthedocs.org/projects/verifone/badge/?version=latest
        :target: https://verifone.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/vilkasgroup/Verifone/badge.svg?branch=master
   :target: https://coveralls.io/github/vilkasgroup/Verifone?branch=master
   :alt: Coveralls status

.. image:: https://pyup.io/repos/github/vilkasgroup/Verifone/shield.svg
     :target: https://pyup.io/repos/github/vilkasgroup/Verifone/
     :alt: Updates



Python package for Verifone


* Free software: MIT license
* Documentation: https://verifone.readthedocs.io.


Features
--------

* Payment with Verifone
* Get available payment methods
* Refund payments

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

